.. module:: archimedes

.. _reference:

################
📚 API Reference
################

This reference provides a detailed overview of the functions and classes in the
Archimedes library.

Modules
==============

.. autosummary::
    :toctree: ../generated/api
    :template: module.rst

    observers
    optimize
    simulate
    spatial
    sysid
    tree


Core Functions
==============

.. autosummary::
    :toctree: ../generated/api
    :template: base.rst

    array
    callback
    codegen
    compile
    discretize
    eye
    field
    grad
    hess
    implicit
    integrator
    interpolant
    jac
    jvp
    minimize
    nlp_solver
    odeint
    ones
    ones_like
    qpsol
    root
    scan
    struct
    StructConfig
    switch
    sym
    sym_like
    UnionConfig
    vjp
    vmap
    zeros
    zeros_like

